@@ -32,7 +32,7 @@ package Apache2::AMFLiteDetectionFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "4.03";
+  $VERSION= "4.04";
   my $CommonLib = new Apache2::AMFCommonLib ();
   my %MobileArray;#=$CommonLib->getMobileArray;
   my %MobileTabletArray;
@@ -46,11 +46,11 @@ package Apache2::AMFLiteDetectionFilter;
   my $configTouchFile;
   my $checkVersion='true';
   my $mobilenable="false";
-  
-  my $urlmobile="http://www.apachemobilefilter.org/param/litemobiledetection.config";
-  my $urlTablet="http://www.apachemobilefilter.org/param/litetabletdetection.config";
-  my $urlTouch="http://www.apachemobilefilter.org/param/litetouchdetection.config";
-  my $urlBot="http://www.apachemobilefilter.org/param/litebotdetection.config";
+  #http://master.dl.sourceforge.net//project/mobilefilter/litetabletdetection.config
+  my $urlmobile="http://master.dl.sourceforge.net//project/mobilefilter/litemobiledetection.config";
+  my $urlTablet="http://master.dl.sourceforge.net//project/mobilefilter/litetabletdetection.config";
+  my $urlTouch="http://master.dl.sourceforge.net//project/mobilefilter/litetouchdetection.config";
+  my $urlBot="http://master.dl.sourceforge.net//project/mobilefilter/litebotdetection.config";
   my $bo;
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
@@ -326,8 +326,7 @@ sub handler {
     }
     my $cookie = $f->headers_in->{Cookie} || '';
     if ($CommonLib->readCookie($cookie) eq 'true' || $CommonLib->readCookie($cookie) eq 'false') {
-	$amf_device_ismobile=$CommonLib->readCookie($cookie);
-	
+	$amf_device_ismobile=$CommonLib->readCookie($cookie);	
     }
     my $amfFull=$CommonLib->readCookie_fullB($cookie);
     if ($query_string) {
